%define _requires_exceptions GLIBC_PRIVATE

#one of valgrind internal library is not linked to libc. Not sure if it should be fixed or not (since all test don't pass anyway), so disable check for now
%define _disable_ld_no_undefined 1

# disable debug package, it can prevent valgrind for working properly
%define debug_package   %{nil}

# (blino) FIXME: reenable qt4 as soon as availble in cauldron
%bcond_without	qt4

Name: 		valgrind
Version:	3.8.1
Release:	%mkrel 1
Summary: 	Memory debugger
License: 	GPLv2+
Group: 		Development/Other
Source0:	http://www.valgrind.org/downloads/%{name}-%{version}.tar.bz2
# From Fedora:
Patch1:		valgrind-3.8.0-cachegrind-improvements.patch
Patch2:		valgrind-3.8.0-openat.patch
Patch3:		valgrind-3.8.0-helgrind-race-supp.patch
Patch4:		valgrind-3.8.0-stat_h.patch
Patch5:		valgrind-3.8.0-capget.patch
Patch6:		valgrind-3.8.0-pie.patch
Patch7:		valgrind-3.8.0-config_h.patch
Patch8:		valgrind-3.8.0-tests.patch
Patch9:		valgrind-3.8.0-enable-armv5.patch
Patch10:	valgrind-3.8.0-ldso-supp.patch
Patch11:	valgrind-3.8.0-x86-backtrace.patch
Patch12:	valgrind-3.8.0-find-buildid.patch

# https://bugs.kde.org/show_bug.cgi?id=305513
Patch102:	valgrind-fix-segv.diff

URL: 		http://valgrind.org/
ExclusiveArch:	%{ix86} x86_64 ppc
BuildRequires:	glibc-static-devel
BuildRequires:	gdb
# (proyvind): build with support for OpenMP, boost & qt4 threads
BuildRequires:	libgomp-devel boost-devel
%if %{with qt4}
BuildRequires:	qt4-devel
%endif
Suggests:	gdb
Obsoletes:	valgrind-plugins

%description
When a program is run under Valgrind's supervision, all reads and
writes of memory are checked, and calls to malloc/new/free/delete are
intercepted. As a result, Valgrind can detect problems such as:

    * Use of uninitialised memory
    * Reading/writing memory after it has been free'd
    * Reading/writing off the end of malloc'd blocks
    * Reading/writing inappropriate areas on the stack
    * Memory leaks -- where pointers to malloc'd blocks are lost forever
    * Passing of uninitialised and/or unaddressible memory to system calls
    * Mismatched use of malloc/new/new [] vs free/delete/delete []

%files
%doc README* AUTHORS FAQ.txt
%{_bindir}/*
%{_libdir}/%{name}
%{_mandir}/man1/*.1*
%{_datadir}/valgrind/*.xml
%{_datadir}/valgrind/default.supp

#--------------------------------------------------------------------

%package	devel
Summary:	%{summary}
Group:		%{group}
Conflicts:	%{name} < 3.6.1-3

%description	devel
Development files required to develop software using valgrind.

%files devel
%dir %{_includedir}/valgrind
%{_includedir}/valgrind/*
%{_libdir}/pkgconfig/%{name}.pc

#--------------------------------------------------------------------

%prep
%setup -q
%apply_patches

%build

# Convert the library paths with /lib or /lib64 in the suppressions to those
# with /usr/lib or /usr/lib64 due to the /usrmove .
perl -pi -e 's!obj:/lib!obj:/usr/lib!g' *.supp *.supp.in

# (From Fedora):
# Filter out some flags that cause lots of valgrind test failures.
# Also filter away -O2, valgrind adds it wherever suitable, but
# not for tests which should be -O0, as they aren't meant to be
# compiled with -O2 unless explicitely requested.
export CFLAGS="`echo " %{optflags} " | sed 's/ -m\(64\|3[21]\) / /g;s/ -fexceptions / /g;s/ -fstack-protector / / g;s/ -Wp,-D_FORTIFY_SOURCE=2 / /g;s/-O2 / /g;s/^ //;s/ $//'`"

# filter out one more flag (unused in FC but causes faillure in mga3:
export CFLAGS="`echo " ${CFLAGS} " | sed -e 's/ -fPIC//'`"
# fix flags in other cases (CXXFLAGS, FFLAGS):
%define optflags $CFLAGS

# rebuild unconditionally because we patch configure.in
autoreconf
%configure2_5x

%make

%install
# Don't strip (prevent valgrind from working properly, as explained in README_PACKAGERS)
export DONT_STRIP=1

# FIXME exporting DONT_STRIP=1 is causing some weird behavior with debug_package
# and causing it to not set DISABLE_DEBUG=1
export DISABLE_DEBUG=1

%makeinstall

mkdir %buildroot/%_datadir/valgrind
mv  %buildroot/%_libdir/valgrind/*.{supp,xml} %buildroot/%_datadir/valgrind

# It's a kludge, but appears to get valgrind to work, because it looks for
# default.supp under %%{_libdir} instead of under %%{_datadir}, where it is
# now installed.
ln -sf %{_datadir}/valgrind/default.supp "$RPM_BUILD_ROOT"/%{_libdir}/valgrind/default.supp

#don't package generated files
rm -f $RPM_BUILD_ROOT%{_libdir}/valgrind/*.supp.in

%check
# Ensure there are no unexpected file descriptors open,
# the testsuite otherwise fails.
cat > close_fds.c <<EOF
#include <stdlib.h>
#include <unistd.h>
int main (int argc, char *const argv[])
{
  int i, j = sysconf (_SC_OPEN_MAX);
  if (j < 0)
    exit (1);
  for (i = 3; i < j; ++i)
    close (i);
  execvp (argv[1], argv + 1);
  exit (1);
}
EOF
gcc $RPM_OPT_FLAGS -o close_fds close_fds.c

for i in `find . -type f \( -name *-amd64-linux -o -name *-x86-linux -o -name *-ppc*-linux \)`; do
  case "`file $i`" in
    *ELF*executable*statically\ linked*)
      objcopy -R .debug_loc -R .debug_frame -R .debug_ranges $i
  esac
done

make check || :
# some tests are known to fail,
# just check no more tests are failing than Fedora ;)
echo ===============TESTING===================
# Cancel this temporarily because the tests hang on x86-64:
# http://thread.gmane.org/gmane.comp.debugging.valgrind/11792
# ./close_fds make regtest || :
echo ===============END TESTING===============



%changelog
* Fri Sep 28 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.8.1-1mdv2012.0
+ Revision: 817819
- version update 3.8.1 and patchset rediff

* Tue Aug 28 2012 Alexander Khrukin <akhrukin@mandriva.org> 3.8.0-1
+ Revision: 815875
- version update 3.8.0 synced with mageia and fedora

  + Franck Bui <franck.bui@mandriva.com>
    - Allow package building on ARM

* Thu Jul 19 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 3.7.0-3
+ Revision: 810302
- sync patches with fedora

* Sat Feb 25 2012 Paulo Andrade <pcpa@mandriva.com.br> 3.7.0-2
+ Revision: 780764
- Rebuild for glibc-2.15.
- Rebuild for glibc-2.15.

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - update buildrequires on 'libgomp-devel' to 'gomp-devel'

* Sat Nov 26 2011 Paulo Andrade <pcpa@mandriva.com.br> 3.7.0-1
+ Revision: 733536
- Update to latest upstream release.

* Sun Sep 04 2011 Paulo Andrade <pcpa@mandriva.com.br> 3.6.1-6
+ Revision: 698233
- Rebuild

* Sun Jul 24 2011 Per Øyvind Karlsen <peroyvind@mandriva.org> 3.6.1-5
+ Revision: 691404
- sync with fedora valgrind-3.6.1-5

* Tue May 03 2011 Per Øyvind Karlsen <peroyvind@mandriva.org> 3.6.1-4
+ Revision: 664806
- rebuild against new glibc

* Wed Apr 27 2011 Per Øyvind Karlsen <peroyvind@mandriva.org> 3.6.1-3
+ Revision: 659522
- build -debug package
- fix striipping (or rather no stripping) of relevant libraries

* Thu Apr 07 2011 Paulo Andrade <pcpa@mandriva.com.br> 3.6.1-2
+ Revision: 651798
- Rebuild with newer gcc and glibc

* Sun Mar 06 2011 Matthew Dawkins <mattydaw@mandriva.org> 3.6.1-1
+ Revision: 642351
- new version 3.6.1

* Wed Nov 03 2010 Paulo Andrade <pcpa@mandriva.com.br> 3.6.0-1mdv2011.0
+ Revision: 593038
- Update to valgrind 3.6.0

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - build with support for OpenMP, boost & qt4 threads

* Mon Dec 07 2009 Paulo Andrade <pcpa@mandriva.com.br> 3.5.0-2mdv2010.1
+ Revision: 474521
- Correct valgrind to work with glibc-2.11.

* Wed Aug 26 2009 Eugeni Dodonov <eugeni@mandriva.com> 3.5.0-1mdv2010.0
+ Revision: 421314
- updated to 3.5.0

* Thu Jun 25 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 3.4.1-3mdv2010.0
+ Revision: 389173
- add wildcards after GLIBC_VERSION to match any library micro versions as well (P4 from Fedora)
- redirect x86_64 ld.so strlen early (P3, RH bug #495645)

* Tue Jun 02 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 3.4.1-2mdv2010.0
+ Revision: 382232
- Rebuild with newer glibc (#51374).

* Thu Mar 05 2009 Frederic Crozat <fcrozat@mandriva.com> 3.4.1-1mdv2009.1
+ Revision: 348875
- Release 3.4.1
- Regenerate patch0
- Remove patch1 (merged upstream)

* Thu Jan 15 2009 Frederic Crozat <fcrozat@mandriva.com> 3.4.0-1mdv2009.1
+ Revision: 329847
- Release 3.4.0
- Remove patches 3, 8 (merged upstream)
- Regenerate patches 0 & 1

* Mon Jun 30 2008 Frederic Crozat <fcrozat@mandriva.com> 3.3.1-2mdv2009.0
+ Revision: 230240
- Update patch8 with upstream fix

* Thu Jun 26 2008 Frederic Crozat <fcrozat@mandriva.com> 3.3.1-1mdv2009.0
+ Revision: 229225
- Release 3.3.1
- Remove patches 4, 5, 6, 7 (merged upstream)
- Don't regenerate debug package, all debug info should stay in valgrind binaries

* Fri May 30 2008 Paulo Andrade <pcpa@mandriva.com.br> 3.3.0-5mdv2009.0
+ Revision: 213483
- Don't supress warnings only if the binary has been explicitly linked
  with libraries at /usr/X11*/lib*.

  + Frederic Crozat <fcrozat@mandriva.com>
    - Rebuild with glibc 4.3 / glibc 2.8
    - run make test in check section
    - Patch0 (Fedora): add cachegrind improvement
    - Patch1 (Fedora): fix pkgconfig file (RH bug #213149)
    - Patch2 (Fedora): fix openat handling (RH bug #208097)
    - Patch3 (Fedora): suppress pthread_barrier_wait in helgrind
    - Patch4 (Fedora): add suppression for glibc 2.7
    - Patch5 (Fedora): add support for glibc 2.8
    - Patches6, 7 (Fedora): add more syscalls
    - Patch8: fix malloc_free_fill test when glibc >= 2.7

* Thu Feb 21 2008 Adam Williamson <awilliamson@mandriva.org> 3.3.0-3mdv2008.1
+ Revision: 173469
- suggests gdb (#37755)

* Thu Feb 14 2008 Adam Williamson <awilliamson@mandriva.org> 3.3.0-2mdv2008.1
+ Revision: 167680
- new license policy
- drop bogus doc install hacks
- buildrequires gdb (#37739)
- spec clean
- drop Source1 (it's not actually used)

  + Olivier Blin <blino@mandriva.org>
    - restore BuildRoot

* Tue Dec 18 2007 trem <trem@mandriva.org> 3.3.0-1mdv2008.1
+ Revision: 131903
- update to 3.3.0
- remove patch for glibc-2.6

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Aug 06 2007 Olivier Blin <blino@mandriva.org> 3.2.3-2mdv2008.0
+ Revision: 59231
- use generic man page extension in files list (for lzma)
- add glibc-2.6 support (patch from Gentoo)

